@@ -27,7 +27,7 @@
 
 #include <Lum/Model/Adjustment.h>
 #include <Lum/Model/Calendar.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Time.h>
 
