@@ -20,7 +20,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 #include <Lum/OS/DrawInfo.h>
 
@@ -49,7 +49,8 @@ public:
 
   void CalcSize();
 
-  void Draw(int x, int y, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);
 };
